@@ -19,7 +19,7 @@ use SIRTX::VM::Assembler;
 
 use parent 'Data::Identifier::Interface::Userdata';
 
-our $VERSION = v0.09;
+our $VERSION = v0.10;
 
 my %_die_raen = (code => 0, P => 7, codeX => 0, S => 2, T => 4+1);
 
@@ -704,12 +704,20 @@ sub as_text {
 
                 if ($type eq 'reg') {
                     $command .= sprintf(' r%u', $self->{$dst});
-                } elsif ($type eq 'sni:' && $dst eq 'extra[]') {
-                    $command .= sprintf(' sni:%u', shift(@extra));
+                } elsif ($type =~ /^(?:sni|raen):$/ && $dst eq 'extra[]') {
+                    $command .= sprintf(' %s%u', $type, shift(@extra));
                 } elsif ($type eq 'int_half' && $dst eq 'extra[]') {
                     $command .= sprintf(' %u', shift(@extra)*2);
+                } elsif ($type eq 'int_rel4' && $dst eq 'extra[]') {
+                    $command .= sprintf(' %u', shift(@extra)*2 + $self->{pos} + 4);
                 } elsif ($type eq 'int' && $dst eq 'extra[]') {
                     $command .= sprintf(' %u', shift(@extra));
+                } elsif ($type eq 'undef' && $dst eq 'undef') {
+                    $command .= ' undef';
+                } elsif ($type eq 'autodie' && $dst eq 'true') {
+                    $command =~ s/^(\S+)(\s?)/$1!$2/;
+                } elsif ($type eq 'autodie' && $dst eq 'false') {
+                    $command =~ s/^(\S+)(\s?)/$1?$2/;
                 } else {
                     $command = undef;
                     last;
@@ -747,7 +755,7 @@ sub as_text {
     }
 
     unless (defined $command) {
-        $command  = sprintf('.byte 0x%02x 0x%02u', $self->{first}, $self->{second});
+        $command  = sprintf('.byte 0x%02x 0x%02x', $self->{first}, $self->{second});
         $command .= ', '.join(' ', map {sprintf('0x%02x', ord)} split(//, $self->{extra})) if defined $self->{extra};
     }
 
@@ -790,8 +798,9 @@ sub _name { # TODO: Private for now, might be exposed later on
     croak 'Unknown/no name for opcode';
 }
 
-sub _start_offsets {
+sub _extra {
     my ($self, @opts) = @_;
+    my %res = (type => 'opcode');
 
     croak 'Stray options passed' if scalar @opts;
 
@@ -801,19 +810,24 @@ sub _start_offsets {
         my $T = $self->{T};
 
         if ($T == 1) {
-            return (unpack('n', $self->{extra})*2);
+            $res{start_offsets} = [unpack('n', $self->{extra})*2];
         }
     } elsif ($self->{first} == 0x06 && $self->{codeX} == 0 && $self->{S} == 7 && defined($self->{pos})) {
         my $T = $self->{T};
+        my $length;
 
         if ($T == 1) {
-            return (unpack('n', $self->{extra})*2 + $self->{pos} + 4);
+            $length = unpack('n', $self->{extra})*2;
         } elsif ($T == 2) {
-            return (unpack('N', $self->{extra})*2 + $self->{pos} + 4);
+            $length = unpack('N', $self->{extra})*2;
         }
+
+        $res{start_offsets} = [$length + $self->{pos} + 4];
+        $res{length}        = $length;
+        $res{type}          = 'chunk';
     }
 
-    return ();
+    return %res;
 }
 
 foreach my $key (keys %_simple_opcodes) {
@@ -898,7 +912,7 @@ SIRTX::VM::Opcode - module for single SIRTX VM opcodes
 
 =head1 VERSION
 
-version v0.09
+version v0.10
 
 =head1 SYNOPSIS
 
